'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var FormControlMixin = {
    propTypes: {
        onChange: _react2.default.PropTypes.func,
        value: _react2.default.PropTypes.any,
        isValid: _react2.default.PropTypes.bool,
        errorMessage: _react2.default.PropTypes.string,
        onError: _react2.default.PropTypes.func,
        force: _react2.default.PropTypes.bool // if false, ignore errors when value is undefined
    },
    getDefaultProps: function getDefaultProps() {
        return {
            isValid: false
        };
    },
    getInitialState: function getInitialState() {
        return {
            force: this.props.force
        };
    },
    shouldCallOnError: function shouldCallOnError() {

        // able to call onError() when
        // 1. value exists(not undefined) and invalid
        // 2. invalid and force is true(ignore value exists or not)
        var _props = this.props;
        var isValid = _props.isValid;
        var value = _props.value;
        var force = this.state.force;


        return !isValid && (value !== undefined || force);
    },
    callError: function callError() {
        var _props2 = this.props;
        var onError = _props2.onError;
        var isValid = _props2.isValid;
        var errorMessage = _props2.errorMessage;

        this.handleError && this.handleError(!isValid, errorMessage);
        onError && onError(!isValid, errorMessage);
    },
    componentDidMount: function componentDidMount() {

        if (this.shouldCallOnError()) {
            this.callError();
        }
    },
    componentDidUpdate: function componentDidUpdate() {
        if (this.shouldCallOnError()) {
            this.callError();
        }
    }
};

exports.default = FormControlMixin;